﻿using UnityEngine;
using System.Collections;

public class PlayerController : MonoBehaviour 
{	
	// public variable will appear in Unity inspector for all objects with this attached script
	public float speed;

	// display for number of pickups collected
	public GUIText countText;

	// display when all pickups are collected
	public GUIText winText;

	// variable to hold count value
	private int count;

	void Start()
	{
		// set count to 0 when the game begins
		count = 0;

		// see function below
		SetCountText ();

		// set initial display to a blank string
		winText.text = "";
	}

	// use this update for changes that require physics
	void FixedUpdate ()
	{
			// grabs player input from the keyboard and transfers to Rigidbody physics component
			float moveHorizontal = Input.GetAxis ("Horizontal");
			float moveVertical = Input.GetAxis ("Vertical");

			// new Vector3 variable uses keyboard input for its values: x = horiz key value, y= 0.0f (ball doesn't move up) and z = vert key value
			Vector3 movement = new Vector3 (moveHorizontal, 0.0f, moveVertical);
			
			// applies input and modulates with speed value; Time.deltaTime smoothes the whole process
			rigidbody.AddForce(movement * speed * Time.deltaTime);
	}

	// called every time a trigger collider is touched
	void OnTriggerEnter(Collider other)
	{
		// if the tag matches "PickUp", make it inactive
		// tags must be set in the Unity editor Tag List; tag is applied to the Prefab so that all instances are tagged identically
		if (other.gameObject.tag == "PickUp") 
		{
			other.gameObject.SetActive (false);
			// increments the count value
			count++;
			// update text display
			SetCountText ();
		}
	}

	// set starting value of GUI text display and print to the GUI Text field
	void SetCountText()
	{
		countText.text = "Count: " + count.ToString();

		// display message when all pickups have been collected
		if (count >= 12) 
		{
			winText.text = "YOU WIN!";
		}
	}


}